==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/SinkInfoFluent.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import java.lang.Boolean;

public interface SinkInfoFluent<A extends SinkInfoFluent<A>> extends Fluent<A>{


    public Boolean isUniqueWriterIdentity();
    public A withUniqueWriterIdentity(Boolean uniqueWriterIdentity);
    public Boolean hasUniqueWriterIdentity();
    public A withNewUniqueWriterIdentity(String arg1);
    public A withNewUniqueWriterIdentity(boolean arg1);
    public Boolean isUpdateDestination();
    public A withUpdateDestination(Boolean updateDestination);
    public Boolean hasUpdateDestination();
    public A withNewUpdateDestination(String arg1);
    public A withNewUpdateDestination(boolean arg1);
    public Boolean isUpdateFilter();
    public A withUpdateFilter(Boolean updateFilter);
    public Boolean hasUpdateFilter();
    public A withNewUpdateFilter(String arg1);
    public A withNewUpdateFilter(boolean arg1);
    public Boolean isUpdateIncludeChildren();
    public A withUpdateIncludeChildren(Boolean updateIncludeChildren);
    public Boolean hasUpdateIncludeChildren();
    public A withNewUpdateIncludeChildren(String arg1);
    public A withNewUpdateIncludeChildren(boolean arg1);
    public String getDestination();
    public A withDestination(String destination);
    public Boolean hasDestination();
    public String getFilter();
    public A withFilter(String filter);
    public Boolean hasFilter();
    public String getId();
    public A withId(String id);
    public Boolean hasId();



}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/SinkInfoFluent.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import java.lang.Boolean;

public interface SinkInfoFluent<A extends SinkInfoFluent<A>> extends Fluent<A>{


    public Boolean isUniqueWriterIdentity();
    public A withUniqueWriterIdentity(Boolean uniqueWriterIdentity);
    public Boolean hasUniqueWriterIdentity();
    public A withNewUniqueWriterIdentity(String arg1);
    public A withNewUniqueWriterIdentity(boolean arg1);
    public Boolean isUpdateDestination();
    public A withUpdateDestination(Boolean updateDestination);
    public Boolean hasUpdateDestination();
    public A withNewUpdateDestination(String arg1);
    public A withNewUpdateDestination(boolean arg1);
    public Boolean isUpdateFilter();
    public A withUpdateFilter(Boolean updateFilter);
    public Boolean hasUpdateFilter();
    public A withNewUpdateFilter(String arg1);
    public A withNewUpdateFilter(boolean arg1);
    public Boolean isUpdateIncludeChildren();
    public A withUpdateIncludeChildren(Boolean updateIncludeChildren);
    public Boolean hasUpdateIncludeChildren();
    public A withNewUpdateIncludeChildren(String arg1);
    public A withNewUpdateIncludeChildren(boolean arg1);
    public String getDestination();
    public A withDestination(String destination);
    public Boolean hasDestination();
    public A withNewDestination(String arg1);
    public A withNewDestination(StringBuilder arg1);
    public A withNewDestination(StringBuffer arg1);
    public String getFilter();
    public A withFilter(String filter);
    public Boolean hasFilter();
    public A withNewFilter(String arg1);
    public A withNewFilter(StringBuilder arg1);
    public A withNewFilter(StringBuffer arg1);
    public String getId();
    public A withId(String id);
    public Boolean hasId();
    public A withNewId(String arg1);
    public A withNewId(StringBuilder arg1);
    public A withNewId(StringBuffer arg1);



}
